@@ -1,5 +1,6 @@
-use general_pub_sub::{Client, PubSub};
+use general_pub_sub::{Client, Message, PubSub};
 use std::{
+    borrow::Borrow,
     io::BufRead,
     net::{TcpListener, TcpStream},
 };
@@ -33,11 +34,14 @@ impl Client<SocketAddr, &str> for TcpClient {
         self.id
     }
 
-    fn send(&mut self, message: &str) {
-        if let Result::Err(error) = self
-            .stream
-            .write(format!("Client ({}) Received: {}\n", self.id, message).as_bytes())
-        {
+    fn send(&mut self, message: &Message<&str>) {
+        if let Result::Err(error) = self.stream.write(
+            format!(
+                "Client ({}) Received Message from Channel ({}): {}\n",
+                self.id, message.source, message.contents
+            )
+            .as_bytes(),
+        ) {
             println!("Failed to write response to client: {}", error);
         }
     }
@@ -51,22 +55,24 @@ fn main() {
 
     let mut pubsub = PubSub::new();
 
-    std::thread::spawn(move || match TcpStream::connect("localhost:3333") {
-        Ok(stream) => {
-            println!("Successfully connected to server. Awaiting messages from channel.");
+    for _ in 0..5 {
+        std::thread::spawn(move || match TcpStream::connect("localhost:3333") {
+            Ok(stream) => {
+                println!("Successfully connected to server. Awaiting messages from channel.");
 
-            let reader = BufReader::new(stream);
-            for message in reader.lines() {
-                println!(
-                    "Received message from server:\n\t{}",
-                    message.expect("Could not read message.")
-                );
+                let reader = BufReader::new(stream);
+                for message in reader.lines() {
+                    println!(
+                        "Received message from server:\n\t{}",
+                        message.expect("Could not read message.")
+                    );
+                }
             }
-        }
-        Err(e) => {
-            println!("Failed to connect to server: {}", e);
-        }
-    });
+            Err(e) => {
+                println!("Failed to connect to server: {}", e);
+            }
+        });
+    }
 
     for stream in listener.incoming() {
         match stream {
@@ -80,7 +86,12 @@ fn main() {
                     .sub_client(client.clone(), channel)
                     .expect("Failed to subscribe to channel.");
 
-                pubsub.pub_message(channel, "Hello from pubsub server!");
+                // THIS IS NAUGHTY!  DON'T DO THIS IN REAL LIFE!
+                let message = &*Box::leak(
+                    format!("A new client ({}) pubsub server!", ip_addr).into_boxed_str(),
+                );
+
+                pubsub.pub_message(channel, message);
             }
             Err(e) => {
                 println!("Error establishing connection: {}", e);
