@@ -1,4 +1,4 @@
-use general_pub_sub::{Client, PubSub};
+use general_pub_sub::{Client, Message, PubSub};
 
 #[derive(Clone, Copy)]
 struct BasicClient {
@@ -16,8 +16,11 @@ impl Client<u32, &str> for BasicClient {
         self.id
     }
 
-    fn send(&mut self, message: &str) {
-        println!("Client ({}) Received: {}", self.id, message);
+    fn send(&mut self, message: &Message<&str>) {
+        println!(
+            "Client ({}) Received Message from Channel ({}): {}",
+            self.id, message.source, message.contents
+        );
     }
 }
 
@@ -34,23 +37,23 @@ fn main() {
 
     pubsub.add_client(client_one);
 
-    if let Result::Err(unexpected_error) = pubsub.sub_client(client_one, all_channels) {
-        println!("This should not happen: {}", unexpected_error);
-    }
+    pubsub
+        .sub_client(client_one, all_channels)
+        .expect("This should not happen");
 
     pubsub.pub_message(channel_a, "Hello from Channel A");
     pubsub.pub_message(channel_b, "Hello from Channel B");
     pubsub.pub_message(channel_c, "Hello from Channel C");
 
-    if let Result::Err(unexpected_error) = pubsub.sub_client(client_one, channel_a) {
-        println!("This should not happen: {}", unexpected_error);
-    }
+    pubsub
+        .sub_client(client_one, channel_a)
+        .expect("This should not happen");
 
     pubsub.pub_message(channel_a, "Client 1 should only receive this once.");
 
-    if let Result::Err(unexpected_error) = pubsub.unsub_client(client_one, all_channels) {
-        println!("This should not happen: {}", unexpected_error);
-    }
+    pubsub
+        .unsub_client(client_one, all_channels)
+        .expect("This should not happen");
 
     pubsub.pub_message(channel_b, "Nobody should receive this message");
 }
